@@ -18,11 +18,12 @@ if [ "Windows_NT" = "$OS" ]; then # Magic variable in cygwin
     PYMONGOCRYPT_LIB=${MONGOCRYPT_DIR}/nocrypto/bin/mongocrypt.dll
     PYMONGOCRYPT_LIB_CRYPTO=$(cygpath -m ${MONGOCRYPT_DIR}/bin/mongocrypt.dll)
     export PYMONGOCRYPT_LIB=$(cygpath -m $PYMONGOCRYPT_LIB)
-    PYTHONS=("C:/python/Python38/python.exe"
-             "C:/python/Python39/python.exe"
+    PYTHONS=("C:/python/Python39/python.exe"
              "C:/python/Python310/python.exe"
              "C:/python/Python311/python.exe"
-             "C:/python/Python312/python.exe")
+             "C:/python/Python312/python.exe"
+             "C:/python/Python313/python.exe"
+             "C:/python/Python314/python.exe")
     export CRYPT_SHARED_PATH=../crypt_shared/bin/mongo_crypt_v1.dll
     C:/python/Python310/python.exe drivers-evergreen-tools/.evergreen/mongodl.py --component crypt_shared \
       --version latest --out ../crypt_shared/
@@ -34,6 +35,8 @@ elif [ "Darwin" = "$(uname -s)" ]; then
           "/Library/Frameworks/Python.framework/Versions/3.10/bin/python3"
           "/Library/Frameworks/Python.framework/Versions/3.11/bin/python3"
           "/Library/Frameworks/Python.framework/Versions/3.12/bin/python3"
+          "/Library/Frameworks/Python.framework/Versions/3.13/bin/python3"
+          "/Library/Frameworks/Python.framework/Versions/3.14/bin/python3"
           )
 
     export CRYPT_SHARED_PATH="../crypt_shared/lib/mongo_crypt_v1.dylib"
@@ -55,12 +58,13 @@ else
           "/opt/mongodbtoolchain/v4/bin/python3"
         )
     else
-        PYTHONS=("/opt/python/3.8/bin/python3"
+        PYTHONS=(
           "/opt/python/3.9/bin/python3"
           "/opt/python/3.10/bin/python3"
           "/opt/python/3.11/bin/python3"
           "/opt/python/3.12/bin/python3"
           "/opt/python/3.13/bin/python3"
+          "/opt/python/3.14/bin/python3"
         )
     fi
     /opt/mongodbtoolchain/v3/bin/python3 drivers-evergreen-tools/.evergreen/mongodl.py --component \
@@ -72,7 +76,7 @@ for PYTHON_BINARY in "${PYTHONS[@]}"; do
     $PYTHON_BINARY -c 'import sys; print(sys.version)'
     git clean -dffx
     createvirtualenv $PYTHON_BINARY .venv
-    python -m pip install --prefer-binary -v -e ".[test]"
+    python -m pip install --prefer-binary -v -e ".[test]" || python -m pip install --pre --prefer-binary -v -e ".[test]"
     echo "Running tests with crypto enabled libmongocrypt..."
     PYMONGOCRYPT_LIB=$PYMONGOCRYPT_LIB_CRYPTO python -c 'from pymongocrypt.binding import lib;assert lib.mongocrypt_is_crypto_available(), "mongocrypt_is_crypto_available() returned False"'
     PYMONGOCRYPT_LIB=$PYMONGOCRYPT_LIB_CRYPTO python -m pytest -v --ignore=test/performance .
@@ -86,7 +90,7 @@ for PYTHON_BINARY in "${PYTHONS[@]}"; do
 done
 
 # Verify the sbom file
-LIBMONGOCRYPT_VERSION=$(cat ./libmongocrypt-version.txt)
+LIBMONGOCRYPT_VERSION=$(cat ./scripts/libmongocrypt-version.txt)
 EXPECTED="pkg:github/mongodb/libmongocrypt@$LIBMONGOCRYPT_VERSION"
 if grep -q $EXPECTED sbom.json; then
   echo "SBOM is up to date!"
