@@ -3,19 +3,19 @@
 
 #include <bson/bson.h>
 
-#include <mlib/endian.h>
-#include <mlib/int128.h>
-#include <mlib/macros.h>
+#include <mc-mlib/endian.h>
+#include <mc-mlib/int128.h>
+#include <mc-mlib/macros.h>
 
 // Conditional preprocessor definition set by the usage of an intel_dfp from
 // the ImportDFP.cmake script:
 #ifndef MONGOCRYPT_INTELDFP
 // Notify includers that Decimal128 is not available:
-#define MONGOCRYPT_HAVE_DECIMAL128_SUPPORT 0
+#define MONGOCRYPT_HAVE_DECIMAL128_SUPPORT() false
 
 #else // With IntelDFP:
 // Tell includers that Decimal128 is okay:
-#define MONGOCRYPT_HAVE_DECIMAL128_SUPPORT 1
+#define MONGOCRYPT_HAVE_DECIMAL128_SUPPORT() true
 
 // Include the header that declares the DFP functions, which may be macros that
 // expand to renamed symbols:
@@ -607,7 +607,7 @@ static inline char *mc_dec128_to_new_decimal_string(mc_dec128 d) {
     }
 }
 
-static inline mc_dec128 mc_dec128_from_bson_iter(bson_iter_t *it) {
+static inline mc_dec128 mc_dec128_from_bson_iter(const bson_iter_t *it) {
     bson_decimal128_t b;
     if (!bson_iter_decimal128(it, &b)) {
         mc_dec128 nan = MC_DEC128_POSITIVE_NAN;
