@@ -19,7 +19,7 @@
 
 #include <bson/bson.h>
 
-#include "mlib/str.h"
+#include "mc-mlib/str.h"
 
 #include "mongocrypt-buffer-private.h"
 #include "mongocrypt-endpoint-private.h"
@@ -84,6 +84,8 @@ typedef struct {
     mc_array_t named_mut;
 } _mongocrypt_opts_kms_providers_t;
 
+typedef bool (*_mongocrypt_contention_factor_fn)(int64_t exclusive_upper_bound, int64_t *out);
+
 void _mongocrypt_opts_kms_providers_init(_mongocrypt_opts_kms_providers_t *kms_providers);
 
 bool _mongocrypt_parse_kms_providers(mongocrypt_binary_t *kms_providers_definition,
@@ -105,6 +107,9 @@ typedef struct {
     mongocrypt_hmac_fn sign_rsaes_pkcs1_v1_5;
     void *sign_ctx;
 
+    // Support overriding random contentionFactor (when null, default) with a custom setter.
+    _mongocrypt_contention_factor_fn contention_factor_fn;
+
     /// Keep an array of search paths for finding the crypt_shared library
     /// during mongocrypt_init()
     int n_crypt_shared_lib_search_paths;
@@ -118,8 +123,6 @@ typedef struct {
     bool use_need_mongo_collinfo_with_db_state;
     bool bypass_query_analysis;
 
-    // Use the Queryable Encryption Range V2 protocol.
-    bool use_range_v2;
 } _mongocrypt_opts_t;
 
 void _mongocrypt_opts_kms_providers_cleanup(_mongocrypt_opts_kms_providers_t *kms_providers);
@@ -140,6 +143,10 @@ bool _mongocrypt_opts_kms_providers_validate(_mongocrypt_opts_t *opts,
                                              _mongocrypt_opts_kms_providers_t *kms_providers,
                                              mongocrypt_status_t *status) MONGOCRYPT_WARN_UNUSED_RESULT;
 
+// For testing only: register a custom contention factor function with crypt.
+void _mongocrypt_opts_set_contention_factor_fn(mongocrypt_t *crypt,
+                                               _mongocrypt_contention_factor_fn contention_factor_fn);
+
 /*
  * Parse an optional UTF-8 value from BSON.
  * @dotkey may be a dot separated key like: "a.b.c".
