@@ -33,10 +33,11 @@
 #endif
 
 #include "mc-check-conversions-private.h"
+#include "mongocrypt-dll-private.h"
 #include "mongocrypt-private.h" // CLIENT_ERR
 #include "mongocrypt-util-private.h"
 
-#include "mlib/thread.h"
+#include "mc-mlib/thread.h"
 
 #include <errno.h>
 #include <math.h> // isinf, isnan, isfinite
@@ -62,7 +63,7 @@ current_module_result current_module_path(void) {
     int ret_error = 0;
 #ifdef _WIN32
     DWORD acc_size = 512;
-    while (!ret_str.data && !ret_error) {
+    while (!ret_str.raw.data && !ret_error) {
         // Loop until we allocate a large enough buffer or get an error
         wchar_t *path = calloc(acc_size + 1, sizeof(wchar_t));
         SetLastError(0);
@@ -84,7 +85,9 @@ current_module_result current_module_path(void) {
     // Darwin/BSD/glibc define extensions for finding dynamic library info from
     // the address of a symbol.
     Dl_info info = {0};
+    MC_BEGIN_CAST_FUNCTION_TYPE_STRICT_IGNORE
     int rc = dladdr((const void *)current_module_path, &info);
+    MC_END_CAST_FUNCTION_TYPE_STRICT_IGNORE
     if (rc == 0) {
         // Failed to resolve the symbol
         ret_error = ENOENT;
